# Monostatic backscattering strength at the bottom as a function of bottom type. 
# The APL-UW model at 30 kHz
# Data from APL-UW High-Frequency Ocean Environmental Acoustic Models Handbook (pages 145-147)

from numpy import *
from scipy.io import *
from scipy import interpolate
from matplotlib.pyplot import *

nthetas = 360
thetai = linspace(1,90,nthetas)

thetas =  array([1, 2, 3, 5, 7, 10, 20, 40, 60, 70, 80, 85, 88, 89, 90]) # in degrees
frequencies = array([10.0,15.0,20.0,25.0,30.0,40.0,60.0,80.0,100.0]) # in kHz

data = loadtxt('roughrock.txt')   ; s = data[:,4]; f = interpolate.interp1d(thetas,s,'cubic'); s1 = f(thetai)
data = loadtxt('rock.txt')        ; s = data[:,4]; f = interpolate.interp1d(thetas,s,'cubic'); s2 = f(thetai)
data = loadtxt('sandygravel.txt') ; s = data[:,4]; f = interpolate.interp1d(thetas,s,'cubic'); s3 = f(thetai)
data = loadtxt('coarsesand.txt')  ; s = data[:,4]; f = interpolate.interp1d(thetas,s,'cubic'); s4 = f(thetai)
data = loadtxt('veryfinesand.txt'); s = data[:,4]; f = interpolate.interp1d(thetas,s,'cubic'); s5 = f(thetai) # Last value at 10 kHz is correct?
data = loadtxt('siltsigma2a.txt') ; s = data[:,4]; f = interpolate.interp1d(thetas,s,'cubic'); s6 = f(thetai) # sigma2 = 0.001

#Lambert's Law and -29dB for bottom
strength_lambert = -29 + 10*log10( ( sin(thetai*pi/180.0) )**2 )

figure(1)
plot(thetai,strength_lambert,'b--',linewidth=2,label=r'Lambert$_{29dB}$')
plot(thetai,s1,'k-.',linewidth=2,label='Rough Rock')
plot(thetai,s2,'k',linewidth=2,label='Rock')
plot(thetai,s3,'k--',linewidth=2,label='Gravel')
plot(thetai,s4,'b-.',linewidth=2,label='Coarse Sand')
plot(thetai,s5,'r',linewidth=2,label='Fine Sand')
plot(thetai,s6,'r-.',linewidth=2,label='Silt')
xlabel('Grazing Angle (deg)')
ylabel('Scattering Strength (dB)')
title('APL-UW model - 30 kHz')
xlim( 0, 90)
ylim(-60,20)
legend(loc=2)
grid(True)

show()

print("done.")
