from numpy import *
from numpy import linalg
from scipy.special import *
from freflco import *

def apl_bottom_bsigma(qi=None,qs=None,phis=None,g2=None,w2=None,kw=None,arho=None,vp=None,dp=None):
    # Bottom bistatic cross section sigma 
    #
    # SYNTAX: sigmakr,sigmapr = apl_bottom_bsigma(thetai,thetas,phis,g2,w2,kw,arho,vp,dp)

    #*******************************************************************************
    # Faro, Qui Set  9 21:00:19 WEST 2021
    # Written by Orlando Camargo Rodriguez
    #*******************************************************************************

#      Reference:
#      APL-UW High-Frequency Ocean Environmental Acoustic Models Handbook
#      Technical Report
#      APL-UW TR 9407
#      October 1994

       kappa = ( 1.0 + 1j*dp )/vp # Eq(33)
       kappaxkappa = kappa*kappa

       alpha = g2/2.0 - 1.0 # Eq(35)
       opa   = 1.0 + alpha
       oma   = 1.0 - alpha
       omta  = 1.0 - alpha*2.0
       twoma = 2.0 - alpha
       twoa  = 2.0*alpha
       ooa   = 1.0/alpha
       oota  = 1.0/twoa
       
       G2ma = gamma( twoma )
       Gopa = gamma( opa   )
       
       cqs   = cos( qs   ); sqs = sin( qs ); cqsxcqs = cqs*cqs
       cqi   = cos( qi   ); sqi = sin( qi ); cqixcqi = cqi*cqi
       cphis = cos( phis )

       Pi = sqrt( kappaxkappa - cqixcqi ) # Eq(32)
       Ps = sqrt( kappaxkappa - cqsxcqs ) # Eq(32)
       
       S = cqs*cqi*cphis 

       d  = 1.0/sqrt(2.0)*sqrt( 1.0 + sqi*sqs - S ) # Eq(76)
       dz = 0.5*( sqi + sqs )                       # Eq(77)
       dt = 0.5*sqrt( cqixcqi - 2.0*S + cqsxcqs )   # Eq(78)
       
       qis = math.asin( d )        # Eq(80)
 
       dK = 2.0*kw*( dt + 0.0001 ) # Eq(83)

       W2dK = w2/( dK**g2 )
        
       Ris = freflco(qis,arho,vp,dp) # Eq(30)
       Ri  = freflco(qi ,arho,vp,dp) + 1.0
       Rs  = freflco(qs ,arho,vp,dp) + 1.0

       RxR   = abs( Ris )**2.0
       RixRi = abs( Ri  )**2.0       
       RsxRs = abs( Rs  )**2.0       
       
       A = RxR/( 8.0*pi )
       A1 = 8.0*alpha*alpha*gamma( oota + 0.5 )
       A2 = gamma( 0.5 )*gamma( ooa )*gamma( oota )
       a  = ( A1/A2 )**twoa                            # Eq(39)
       b = ( a**( 0.5 + 1.0/twoa )*gamma( ooa ) )/twoa # Eq(40)
       E = 2.0*pi*w2*G2ma*( 2.0**( -twoa ) )
       F = alpha*oma*Gopa
       ChxCh = E/F
       q0 = ChxCh*( 2.0**( omta ) )*( kw**( 2.0*oma ) ) # Eq(38)
       C  = ( dt**( 4.0*alpha ) + a*q0*q0*( dz**4.0 ) )**( opa/twoa )
       B = b*q0*( 1.0 + 100.0*dt**4.0 )/C
       G = ( 1.0/arho - 1.0 )*( S - Pi*Ps/arho ) + 1.0 - kappaxkappa/arho
       GxG = abs( G )**2.0

       sigmakr = A*( d**4.0 )*B                        # Eq(79)
       sigmapr = 0.25*( kw**4.0 )*RixRi*RsxRs*GxG*W2dK # Eq(81)
     
       return sigmakr,sigmapr
