from numpy import *
from scipy.special import *
from freflco import *

def apl_bottom_bsigmav(qi=None,qs=None,phis=None,g3=None,w3=None,kw=None,arho=None,vp=None,dp=None):
    # Fluid bottom bistatic volume scattering cross section sigma
    #
    # SYNTAX: sigmav = apl_bottom_bsigmav(thetai,thetas,phis,g3,w3,kw,arho,vp,dp)

    #*******************************************************************************
    # Gambelas, Qui Set  9 21:00:05 WEST 2021
    # Written by Orlando Camargo Rodriguez
    #*******************************************************************************

#      Reference: 
#      APL-UW high-frequency ocean environmental acoustic models handbook
#      Applied Physics Laboratory
#      Technical report, 
#      University of Washington, 1994

       kappa = ( 1.0 + 1j*dp )/vp # Eq(33)
       kappaxkappa = kappa*kappa

       cqs   = cos( qs   ); cqsxcqs = cqs*cqs
       cqi   = cos( qi   ); cqixcqi = cqi*cqi
       cphis = cos( phis )

       S = cqs*cqi*cphis

       pps = sqrt( kappaxkappa - cqsxcqs ) # Eq(32)
       ppi = sqrt( kappaxkappa - cqixcqi ) # Eq(32)

       Rs = freflco(qs,arho,vp,dp) + 1.0
       Ri = freflco(qi,arho,vp,dp) + 1.0
       RsxRs = abs( Rs )**2.0
       RixRi = abs( Ri )**2.0

       Repis = real( ppi + pps )
       Impis = imag( ppi + pps )
       A = 2.0*kw*arho*arho*Impis
       F = S - kappaxkappa - ppi*pps; FxF = abs( F )**2.0
       dt = 0.5*sqrt( cqixcqi + cqsxcqs - 2.0*S ) # Eq(78)
       dk = kw*sqrt( 4.0*dt*dt + Repis*Repis )    # Eq(87)
       Wpp = w3/( dk**g3 )                        # Eq(72)
       sigmav0 = pi/2.0*( kw**4.0 )*FxF*Wpp       # Eq(86)
       sigmav = sigmav0*RixRi*RsxRs/A             # Eq(85)
       
       return sigmav
