from numpy import *
from numpy import linalg
from scipy.special import *
from freflco import *

def apl_bottom_sigmalr(q=None,g2=None,w2=None,kw=None,arho=None,vp=None,dp=None):
    # Fluid bottom backscattering cross section sigma (large roughness)
    #
    # SYNTAX: sigmalr = apl_bottom_sigmalr(thetai,g2,w2,kw,arho,vp,dp)

    #*******************************************************************************
    # Faro, Qui Set  9 20:59:52 WEST 2021
    # Written by Orlando Camargo Rodriguez
    #*******************************************************************************

#      Reference:
#      APL-UW High-Frequency Ocean Environmental Acoustic Models Handbook
#      Technical Report
#      APL-UW TR 9407
#      October 1994

       kxk = kw*kw

#      Eq(54):
       if vp >= 1.001:
          qc = math.acos( 1.0/vp )
       else:
          qc = 2.5613*pi/180.0

       alpha = g2/2.0 - 1.0 # Eq(35)
       opa   = 1.0 + alpha
       oma   = 1.0 - alpha
       ooa   = 1.0/alpha
       
       S1 = ( 2.0*pi*w2 )**( ooa )
       S2 = ( kxk/alpha )**( oma/alpha ) # oma or opa??????
       S3 = 2.0*oma
       sxs = S1*S2/S3         # Eq(41)
       s = abs( sqrt( sxs ) ) # large scale rms slope 
       m = 0.7263*( s**( -1.0/3.0 ) ) # Eq(55)

       R = freflco(0.5*pi,arho,vp,dp)

       RxR = abs( R )**2.0
    
       T6 = ( (1.0 - 2.0/arho)/(vp*vp) + 1.0 )**2.0
       T4 = 0.04682*( s**1.25 )*( vp**3.25 )*T6
       T5 = 1.0 + 3.54*q/qc
       sigma1 = T4/T5
       T3 = 1.0 + 0.81*(qc/q)**2.0
       S = ( sin(pi/T3) )**m
       T1 = sigma1*S
       T7 = 0.0260*RxR
       T9 = 1.0 + ( q - 0.5*pi )**2.0/( 2.6*q*q )
       T8 = sxs*(T9**1.9)*T3
       T2 = T7/T8
       
       sigmalr = T1 + T2  # Eq(53)

       return sigmalr
