from numpy import *
from freflco import *

def apl_bottom_sigmav(qi=None,qs=None,cw=None,freq=None,arho=None,vp=None,dp=None,sigma2=None):
    # Elastic bottom volume cross section sigmav 
    #
    # SYNTAX: sigmav = apl_bottom_sigmav(thetai,thetas,cw,freq,arho,vp,dp,sigma2)

    #*******************************************************************************
    # Faro, Qui Set  9 20:59:22 WEST 2021
    # Written by Orlando Camargo Rodriguez
    #*******************************************************************************

#      Reference: 
#      High-Frequency Seafloor Acoustics

#      No dependence on the bistatic angle? A disk of scattering can't be symmetric!!!!
#      Yet, this produces larger values than the documented in APL-UW 1994. 

       kw = 2.0*pi*freq/cw

       a_p = vp/( 1.0 + 1j*dp ); apxap = a_p*a_p

       cqi = cos( qi ); cqixcqi = cqi*cqi; Pi = sqrt( 1.0/apxap - cqixcqi )
       cqs = cos( qs ); cqsxcqs = cqs*cqs; Ps = sqrt( 1.0/apxap - cqsxcqs )

       alphap = 40.0*pi*freq*dp/( vp*cw*log( 10.0 ) )

       Vwpi = 1.0 + freflco(qi,arho,vp,dp)
       Vwps = 1.0 + freflco(qs,arho,vp,dp)

       VpxVp = abs( Vwpi )**2.0
       VsxVs = abs( Vwps )**2.0

       P = 2.0*kw*arho*arho*( imag( Pi + Ps ) )

       sigmav = sigma2*alphap

       sigma = VpxVp*VsxVs*sigmav/P

       return sigma
