#==================================================================
#  Cross-section disk
#  Faro, Qui Set  9 20:58:24 WEST 2021
#  Written by Orlando Camargo Rodriguez
#==================================================================

from numpy import *
from scipy.io import *
from matplotlib.pyplot import *
from apl_bottom_bsigmav import *
from apl_bottom_bsigma  import *

freqkHz = 10.0
freq    = freqkHz*1000
cw      = 1500.0
kw      = 2.0*pi*freq/cw

# Sandy bottom: 

arho    = 1.940
vp      = 1.113
dp      = 0.0115

g2      = 3.25
w2      = 0.000141
g3      = 3.0
w3      = 0.0004

eta = -2.0

thetai = 45; qi = thetai*pi/180

nthetas = 90
theta = linspace(1.0,90.0,nthetas)

nphis = 361
phis  = linspace(-180,180,nphis)

Sb = zeros((nphis,nthetas))
sigma = zeros((nphis,nthetas))

for j in range(nphis):
    phi = phis[j]*pi/180.0
    for i in range(nthetas):
        q = theta[i]*pi/180.0
        sigmav          = apl_bottom_bsigmav(qi,q,phi,g3,w3,kw,arho,vp,dp) 
        sigmakr,sigmapr = apl_bottom_bsigma( qi,q,phi,g2,w2,kw,arho,vp,dp)
        sigmar = ( sigmakr**eta + sigmapr**eta )**( 1.0/eta )
        sigma[j,i]  = sigmav + sigmar
        Sb[j,i]  = 10*log10( sigmav + sigmar )

[R,Bearings] = meshgrid(theta,phis)

X = R*cos( Bearings*pi/180.0 )
Y = R*sin( Bearings*pi/180.0 )

thetitle = r'Scattering Cross Section, $\theta_i = '+ str(thetai) + '^\circ$'

figure(1)
pcolor(X,Y,sigma,cmap='jet',vmin=0,vmax=1)
colorbar()
axis('off')
title(thetitle)
thetan = arange(15,90,15)
n = thetan.size
for i in range(n):
    s = str( thetan[i] )+r'$^\circ$'
    text(thetan[i],0,s,color='black')
n = 18
for i in range(9):
    s = str( i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

text(-100,0,r'$\pm$180$^\circ$',horizontalalignment='center',verticalalignment='center')

for i in range(9):
    s = str( -i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(-i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

figure(2)
pcolor(X,Y,Sb,cmap='jet',vmin=-30,vmax=-10)
colorbar()
axis('off')
#title(thetitle)
thetan = arange(15,90,15)
n = thetan.size
for i in range(n):
    s = str( thetan[i] )+r'$^\circ$'
    text(thetan[i],0,s,color='white')
n = 18
for i in range(9):
    s = str( i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

text(-100,0,r'$\pm$180$^\circ$',horizontalalignment='center',verticalalignment='center')

for i in range(9):
    s = str( -i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(-i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

show()

print('done.')
