#==================================================================
#  APL-UW High-Frequency Ocean Environmental Acoustic Models Handbook
#  Technical Report
#  APL-UW TR 9407
#  October 1994
#  Figure 2 p.67 (II-11)
#  Faro, Qui Set  9 21:04:48 WEST 2021 
#  Written by Orlando Camargo Rodriguez
#==================================================================

from numpy import *
from matplotlib.pyplot import *
from apl_bub_sigma     import *
from apl_surface_sigma import *

freqkHz = 25; freq = freqkHz*1000

nthetas = 180
thetas  = linspace(1,90,nthetas); q = thetas*pi/180.0; g = 0.5*pi - q; secg = 1.0/cos( g ); p1 = secg**4.0

U = arange(3.0,11.0); U = append(U,15.0); sU = size( U )

qf    = zeros(sU)
sigma = zeros( (sU,nthetas) )

for i in range(sU):
    sxs = 0.034
    Ui = U[i]
    if ( Ui >= 1.0 ):
       sxs = 4.6e-3*log( 2.1*Ui*Ui )
    p2 = 4.0*pi*sxs
    sf90 = 1.0/p2
    x = tan(g)**2.0/sxs
    sf = p1/p2*exp( -x )
    threshold = sf90/( 10**1.5 )
    index = argmax( sf >= threshold )
    qf[i] = q[index]
    for j in range(nthetas):
        sb = apl_bub_sigma(q[j],freq,U[i])
        sr = apl_surface_sigma(q[j],freq,U[i],qf[i])
        sigma[i,j] = sr + sb

SS = 10*log10( sigma )

figure(1)
for i in range(sU):
    plot(thetas,SS[i,])
xlabel('GRAZING ANGLE (deg)',fontsize=18)
ylabel('SCATTERING STRENGTH (dB)',fontsize=18)
title('APL model - 25 kHz',fontsize=18)
ylim(-60,10)
grid(True)

show()

print('done')
