from numpy import *

def apl_bub_sigma(q=None,freq=None,U=None):
    # APL surface bubble backscattering cross section
    #
    # SYNTAX: s = apl_bub_sigma(theta,freq,U)

    #*******************************************************************************
    # Faro, Qui Set  9 21:03:56 WEST 2021
    # Written by Orlando Camargo Rodriguez
    #*******************************************************************************

#      Reference:
#      APL-UW High-Frequency Ocean Environmental Acoustic Models Handbook
#      Technical Report
#      APL-UW TR 9407
#      October 1994

#      "At high bubble densities Eq(2) ... is independent of wind speed." 
    
       fkHz = freq/1000.0
#      Eq(5):
       f2 = ( fkHz/25.0 )**0.85
       if U < 11:
          f1 = -5.2577 + 0.4701*U
          bv = f2*( 10.0**f1 )
       else:
          f1 = -5.2577 + 0.4701*11
          bv11 = f2*( 10.0**f1 )
          f3 = (U/11.0)**3.5
          bv = bv11*f3
       b = bv/sin( q ) # Eq(3)
       dr = 0.0136 # Eq(4) - reradiation damping coefficient
       p1 = bv*dr
       d = 2.55e-2*( fkHz**(1.0/3.0) ) # Eq(6)
       p2 = 4.0*pi*d
       r1 = 1.0 + 8.0*b*exp( -2.0*b ) - exp( -4.0*b )
       r2 = 2.0*b
       r = r1/r2
       s = p1/p2*r # Eq(2)

       return s
