from numpy import *

def apl_surface_sigma(q=None,freq=None,U=None,qf=None):
    # APL surface monostatic model
    #
    # SYNTAX: s = apl_surface_sigma(thetai,freq,U,thetaf)

    #*******************************************************************************
    # Faro, Qui Set  9 21:03:32 WEST 2021
    # Written by Orlando Camargo Rodriguez
    #*******************************************************************************

#      Reference:
#      APL-UW High-Frequency Ocean Environmental Acoustic Models Handbook
#      Technical Report
#      APL-UW TR 9407
#      October 1994

       fkHz = freq/1000.0
       A = 1.3e-5*U # Eq(10)
       sxs = 0.034
       if ( U >= 1.0 ):
          sxs = 4.6e-3*log( 2.1*U*U )
       p2 = 4.0*pi*sxs
       if ( q*180.0/pi <= 85.0 ):
          ssc = A*( (tan(q))**4.0 )
       else:
          ssc = 0.0
       if (U >= 6 ):
          SBL = 1.26e-3/sin(q)*( U**1.57 )*( fkHz**0.85 ) # Eq(28a)
       else:
          SBL = 1.26e-3/sin(q)*( 6**1.57 )*( fkHz**0.85 )*exp( U - 6.0 ) # Eq(28b)
       g = 0.5*pi - q
       secg = 1.0/cos( g )
       p1 = secg**4.0
       x = tan(g)**2.0/sxs
       sf = p1/p2*exp( -x )
       x = 0.524*( qf - q )*180.0/pi # Eq(15)
       f = 1.0/( 1.0 + exp(x) )      # Eq(13)
       sri = f*sf + ( 1.0 - f )*ssc  # Eq(14)
       sr = sri*10**( -SBL/10.0 )    # Eq(16)
       return sr
