#==================================================================
#  Broadband Models for Predicting Bistatic Bottom, Surface,
#  and Volume Scattering Strengths
#  ROGER C. GAUSS
#  ROBERT F. GRAGG
#  DANIEL WURMSER
#  JOSEPH M. FIALKOWSKI
#  Figure4(e), page 18. 
#  Faro, Qui Set  9 21:17:02 WEST 2021
#  Written by Orlando Camargo Rodriguez
#==================================================================

# Table 2, page 14:
# Limestone 2.4 2.7-0.004i 1.5-0.003i 3.3 0.004

from numpy import *
from scipy.io import *
from matplotlib.pyplot import *
from nrl_ebottom_sigma import *

freq = 3000
h0 = 1.0
cw = 1500.0
g2 = 3.3

rho = array([1.4, 2.0, 2.4, 2.7])
cp  = array([0.99-1j*0.002,1.2-1j*0.005,2.7-1j*0.004,3.4-1j*0.006])*cw
cs  = array([0.1-1j*0.0004,0.3-1j*0.077,1.5-1j*0.003,1.8-1j*0.006])*cw
w2  = array([0.000518,0.006957,0.004,0.01862])

nthetas = 181
theta = linspace(5.0,175.0,nthetas)

thetai = 10;
qi = thetai*pi/180.0

nphis = 351
phis  = linspace(-175.0,175.0,nphis)

S     = zeros((nphis,nthetas))
sigma = zeros((nphis,nthetas))

for j in range(nphis):
    phi = phis[j]*pi/180.0
    for i in range(nthetas):
        q = theta[i]*pi/180.0
        sigma[j,i] = nrl_ebottom_sigma(qi,q,freq,cw,cp[2],cs[2],phi,rho[2],g2,w2[2],h0)    

Sb = 10*log10( sigma )

thetitle = r'Scattering Cross Section, $\theta_i = '+ str(thetai) + '^\circ$'

figure(1)
pcolor(theta,phis,Sb,cmap='jet',vmin=-40,vmax=-5)
colorbar()
axis('off')
title( thetitle )

show()

print('done.')
