#==================================================================
#  Figure 4-3: Bottom Loss for Various Bottom Types
#  Faro, Qui Set  9 21:16:03 WEST 2021
#  Written by Orlando Camargo Rodriguez
#==================================================================

from numpy   import *
from matplotlib.pyplot import *
from freflco import *
from ereflco import *

# Miller2015 - Table 4.1 p.32
# [cp] = [cs] = m/s
# [ap] = [as] = dB/lambda
# Bottom parameters for multiple bottom types
#           rhob/rhow  cp/cw   cp   cs       ap  as
# Clay      1.5        1.00    1500 <100     0.2 1.0
# Silt      1.7        1.05    1575  80z^0.3 1.0 1.5
# Sand      1.9        1.1     1650 110z^0.3 0.8 2.5
# Gravel    2.0        1.2     1800 180z^0.3 0.6 1.5
# Moraine   2.1        1.3     1950  600     0.4 1.0
# Chalk     2.2        1.6     2400 1000     0.2 0.5
# Limestone 2.4        2.0     3000 1500     0.1 0.2
# Basalt    2.7        3.5     5250 2500     0.1 0.2

cw = 1500.0

rho = array([1.5,1.7,1.9,2.0,2.1,2.2,2.4,2.7])
cp  = array([1500.0,1575.0,1650.0,1800.0,1950.0,2400.0,3000.0,5250.0])
cs  = array([100.0,0,0,0,600.0,1000.0,1500.0,2500.0])
alphap  = array([0.2,1.0,0.8,0.6,0.4,0.2,0.1,0.1])
alphas  = array([1.0,1.5,2.5,1.5,1.0,0.5,0.2,0.2])

nthetas = 360
theta = linspace(1,90,nthetas)

R = zeros( (8,nthetas) ) + 1j*zeros( (8,nthetas) )

for i in range(nthetas):
    q = theta[i]*pi/180.0
    R[0,i] = ereflco(q,rho[0],cw,cp[0],alphap[0],cs[0],alphas[0])
    R[1,i] = freflco(q,rho[1],cw,cp[1],alphap[1])
    R[2,i] = freflco(q,rho[2],cw,cp[2],alphap[2])
    R[3,i] = freflco(q,rho[3],cw,cp[3],alphap[3])
    R[4,i] = ereflco(q,rho[4],cw,cp[4],alphap[4],cs[4],alphas[4])
    R[5,i] = ereflco(q,rho[5],cw,cp[5],alphap[5],cs[5],alphas[5])
    R[6,i] = ereflco(q,rho[6],cw,cp[6],alphap[6],cs[6],alphas[6])
    R[7,i] = ereflco(q,rho[7],cw,cp[7],alphap[7],cs[7],alphas[7])

L = -20*log10( abs( R ) )

figure(1)
plot(theta,L[0,],'k',linewidth=2,label='Clay')
plot(theta,L[1,],'k-.',linewidth=2,label='Silt')
plot(theta,L[2,],'k',linewidth=2,label='Sand')
plot(theta,L[3,],'k--',linewidth=2,label='Gravel')
plot(theta,L[4,],'b',linewidth=2,label='Moraine')
plot(theta,L[5,],'b-.',linewidth=2,label='Chalk')
plot(theta,L[6,],'b',linewidth=2,label='Limestone')
plot(theta,L[7,],'b--',linewidth=2,label='Basalt')
ylim(0,20)
xlabel('Grazing Angle (deg)' ,fontsize=18)
ylabel('Bottom reflection Loss (dB)',fontsize=18)
#legend(loc=4)
grid(True)

show()

print('done.')

