#==================================================================
#  Scattering strength disk for limestone
#  Faro, Qui Set  9 21:17:59 WEST 2021
#  Written by Orlando Camargo Rodriguez
#==================================================================

from numpy import *
from scipy.io import *
from matplotlib.pyplot import *
from nrl_ebottom_sigma import *

freq = 3000
h0 = 1.0
cw = 1500.0
g2 = 3.3

rho = array([1.4, 2.0, 2.4, 2.7])
cp  = array([0.99-1j*0.002,1.2-1j*0.005,2.7-1j*0.004,3.4-1j*0.006])*cw
cs  = array([0.1-1j*0.0004,0.3-1j*0.077,1.5-1j*0.003,1.8-1j*0.006])*cw
w2  = array([0.000518,0.006957,0.004,0.01862])

nthetas = 90
theta = linspace(1.0,90.0,nthetas)

thetai = 10.0
qi = thetai*pi/180.0

nphis = 181
phis  = linspace(-180.0,180.0,nphis)

S     = zeros((nphis,nthetas))
sigma = zeros((nphis,nthetas))

for j in range(nphis):
    phi = phis[j]*pi/180.0
    for i in range(nthetas):
        q = theta[i]*pi/180.0
        sigma[j,i] = nrl_ebottom_sigma(qi,q,freq,cw,cp[2],cs[2],phi,rho[2],g2,w2[2],h0)    

Sb = 10*log10( sigma )
[R,Bearings] = meshgrid(theta,phis)

X = R*cos( Bearings*pi/180.0 )
Y = R*sin( Bearings*pi/180.0 )

thetitle = r'Scattering Cross Section, $\theta_i = '+ str(thetai) + '^\circ$'

figure(1)
pcolor(X,Y,sigma,cmap='jet',vmin=0,vmax=0.5)
colorbar()
axis('off')
title( thetitle )
thetan = arange(15,90,15)
n = thetan.size
for i in range(n):
    s = str( thetan[i] )+r'$^\circ$'
    text(thetan[i],0,s,color='black')
n = 18
for i in range(9):
    s = str( i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

text(-100,0,r'$\pm$180$^\circ$',horizontalalignment='center',verticalalignment='center')

for i in range(9):
    s = str( -i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(-i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

figure(2)
pcolor(X,Y,Sb,cmap='jet',vmin=-50,vmax=0)
colorbar()
axis('off')
title( thetitle )
thetan = arange(15,90,15)
n = thetan.size
for i in range(n):
    s = str( thetan[i] )+r'$^\circ$'
    text(thetan[i],0,s,color='white')
n = 18
for i in range(9):
    s = str( i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

text(-100,0,r'$\pm$180$^\circ$',horizontalalignment='center',verticalalignment='center')

for i in range(9):
    s = str( -i*20 )+r'$^\circ$'
    text(100*cos(i*2*pi/n),100*sin(-i*2*pi/n),s,horizontalalignment='center',verticalalignment='center')

show()

print('done.')
