from numpy import *

def ereflco(q=None,arho=None,cw=None,cp=None,alphap=None,cs=None,alphas=None):
    # Elastic Bottom reflection coefficient
    #
    # SYNTAX: Vww = ereflco(theta,rho,cw,cp,ap,cs,as)

    #*******************************************************************************
    # Faro, Qui Set  9 21:17:30 WEST 2021
    # Written by Orlando Camargo Rodriguez
    #*******************************************************************************

# High-Frequency Bistatic Scattering Model for Elastic Seafloors
# Darrell R. Jackson
# Technical Memorandum
# APL-UW TM 2-00
# February 2000

       vp    = cp/cw
       dp    = alphap*vp*log( 10 )/( 40.0*pi )
       vt    = cs/cw
       dt    = alphas*vt*log( 10 )/( 40.0*pi )
       a_p  = vp/( 1.0 + 1j*dp )
       a_t  = vt/( 1.0 + 1j*dt )
       apxap = a_p*a_p
       atxat = a_t*a_t
       cosq = cos( q ); sinq = sin(q); cqxcq = cosq*cosq
       sinqp = sqrt( 1.0 - apxap*cqxcq )
       pp = sqrt( 1.0/apxap - cqxcq )  # Eq(18)
       pt = sqrt( 1.0/atxat - cqxcq )  # Eq(18)
       cos2qt  = 2.0*atxat*cqxcq - 1.0 # Eq(23)
       c2qxc2q = cos2qt*cos2qt
       s2qxs2q = 1.0 - c2qxc2q         # Eq(24)
       zwp = arho*sinq*( c2qxc2q/pp + s2qxs2q/pt ) # Eq(22)
 
       Vww = ( zwp - 1.0 )/( zwp + 1.0 )

       return Vww
