#==================================================================
#  JKPS
#  Figure 1.27(a)
#  Faro, Qui Set  9 21:22:10 WEST 2021
#  Written by Orlando Camargo Rodriguez
#==================================================================

from numpy import *
from matplotlib.pyplot import *
from nrl_bub_sigma     import *
from nrl_surface_sigma import *

cw     = 1500
As     = 0.00019
gamma2 =  3.8
freq   = 1500
U = array([20.0,15.0,10.0,5.0,2.5])
w2 = As*U

nthetas = 360
theta = linspace(1,90,nthetas)

ssa = zeros((5,nthetas))

for i in range(nthetas):
    q = theta[i]*pi/180.0
    ss = nrl_surface_sigma(q,q,freq,cw,pi,gamma2,w2[0])
    sb = nrl_bub_sigma(q,q,freq,cw,U[0])
    ssa[0,i] = sb + ss
    ss = nrl_surface_sigma(q,q,freq,cw,pi,gamma2,w2[1])
    sb = nrl_bub_sigma(q,q,freq,cw,U[1])
    ssa[1,i] = sb + ss
    ss = nrl_surface_sigma(q,q,freq,cw,pi,gamma2,w2[2])
    sb = nrl_bub_sigma(q,q,freq,cw,U[2])
    ssa[2,i] = sb + ss
    ss = nrl_surface_sigma(q,q,freq,cw,pi,gamma2,w2[3])
    sb = nrl_bub_sigma(q,q,freq,cw,U[3])
    ssa[3,i] = sb + ss
    ss = nrl_surface_sigma(q,q,freq,cw,pi,gamma2,w2[4])
    sb = nrl_bub_sigma(q,q,freq,cw,U[4])
    ssa[4,i] = sb + ss

SS = 10*log10( ssa )

# Chapman - Harris: valid betwwen 400 and 6400 Hz, w < 15 m/s:
p = U[2]*freq**( 1.0/3.0 )
b = 107*p**( -0.58 )
sCH = 3.3*b*log10( theta/30.0 ) - 42.4*log10( b ) + 2.6;

figure(1)
plot(theta,SS[0,],'k',lineWidth=2,label='20')
plot(theta,SS[1,],'b',lineWidth=2,label='15')
plot(theta,SS[2,],'r',lineWidth=2,label='10')
plot(theta,SS[3,],'g',lineWidth=2,label='5')
plot(theta,SS[4,],'m',lineWidth=2,label='2.5')
plot(theta,sCH,'k--',lineWidth=2,label='C-H 10 m/s')
xlabel('Grazing angle (deg)')
ylabel('Scattering Strength (dB)')
title('NRL model - 1.5 kHz')
xlim(0,90)
ylim(-60,10)
legend(loc=2)
grid(True)

show()

print('done.')
