from numpy import *

def nrl_bub_sigma(theta1=None,theta2=None,freq=None,cw=None,U=None):
   # NRL 
    #
    # SYNTAX: s = nrl_bub_sigma(theta1,theta2,freq,cw,U)

    #*******************************************************************************
    # Faro, Qui Set  9 21:22:25 WEST 2021
    # Written by Orlando Camargo Rodriguez
    # Based on sssbub.m (NRL Code 7144; January 2003)
    #*******************************************************************************

# References: 
# (1) Gauss and Fialkowksi, "A Broadband Model for Predicting Bistatic
#     Surface Scattering Strengths," Proceedings of the Fifth European
#     Conference on Underwater Acoustics, pp. 1165-1170 (2000).
# (2) R.C. Gauss, R.F. Gragg, R.W. Nero, D. Wurmser, and J.M. Fialkowski,
#     "Broadband Models for Predicting Bistatic Bottom, Surface, 
#     and Volume Scattering Strengths," NRL/FR/7100--02-10,042, 

# Compute d given U:
       if ( U > 3.0 )&( U < 7.5 ): 
           d = 0.292625*( (U-3.0)/4.5 )
       elif ( U >= 7.5 ):
           d = 0.557-0.117*U + 0.0109*U**2 
       else:
           d = 0.0

       omega = 2.0*pi*freq
       kw = omega/cw

       S = sin( theta1 )
       R = sin( theta2 )
       S2 = S**2
       R2 = R**2
       A = 0.5*kw*d*S
       B = 0.5*kw*d*R
       A2 = A**2
       B2 = B**2

       X = S2*R2*( 3.0 + 6.0*( A2+B2 ) + 8*( A2-B2 )**2 )
       Y = ( 1.0 + 4.0*A2 )*( 1.0 + 4.0*B2 )*( 1.0 +4.0*( A-B )**2 )*( 1.0 + 4.0*( A+B )**2 )

       s = 0.0019*( kw**3.43 )*( d**5.15 )*( X/Y )

       return s
